# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel  # noqa: F401


class EventSubscription(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    EventSubscription - a model defined in OpenAPI

        id: The id of this EventSubscription.
        callback: The callback of this EventSubscription.
        query: The query of this EventSubscription [Optional].
    """

    id: str
    callback: str
    query: Optional[str] = None


EventSubscription.update_forward_refs()
